@@ -145,10 +145,8 @@ class SeleniumTestability(LibraryComponent):
         "edge": DesiredCapabilities.EDGE,
         "opera": DesiredCapabilities.OPERA,
         "safari": DesiredCapabilities.SAFARI,
-        "phantomjs": DesiredCapabilities.PHANTOMJS,
         "htmlunit": DesiredCapabilities.HTMLUNIT,
         "htmlunitwithjs": DesiredCapabilities.HTMLUNITWITHJS,
-        "android": DesiredCapabilities.ANDROID,
         "iphone": DesiredCapabilities.IPHONE,
     }
 
