@@ -7,6 +7,7 @@ from selenium.webdriver.remote.webelement import WebElement
 try:
     # Only required during development.
     from psutil import Process
+
     ProcessType = Union[Process, int]
 except ModuleNotFoundError:
     pass
@@ -15,7 +16,7 @@ WebElementType = Union[WebElement, EventFiringWebElement]
 LocatorType = Union[WebElementType, EventFiringWebElement, str]
 OptionalBoolType = Optional[bool]
 OptionalStrType = Optional[str]
-OptionalDictType = Optional[str]
+OptionalDictType = Optional[Dict]
 BrowserLogsType = List[str]
 StringArray = List[str]
 FirefoxWebDriverType = Union[Firefox, EventFiringWebDriver]
